@@ -16,15 +16,15 @@
 from collections import OrderedDict
 import functools
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
-from google.api_core.client_options import ClientOptions
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
+from google.api_core.client_options import ClientOptions
 from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -33,12 +33,13 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+
 from google.cloud.service_usage_v1.services.service_usage import pagers
-from google.cloud.service_usage_v1.types import resources
-from google.cloud.service_usage_v1.types import serviceusage
-from .transports.base import ServiceUsageTransport, DEFAULT_CLIENT_INFO
-from .transports.grpc_asyncio import ServiceUsageGrpcAsyncIOTransport
+from google.cloud.service_usage_v1.types import resources, serviceusage
+
 from .client import ServiceUsageClient
+from .transports.base import DEFAULT_CLIENT_INFO, ServiceUsageTransport
+from .transports.grpc_asyncio import ServiceUsageGrpcAsyncIOTransport
 
 
 class ServiceUsageAsyncClient:
@@ -216,14 +217,13 @@ class ServiceUsageAsyncClient:
         r"""Enable a service so that it can be used with a
         project.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
 
-            def sample_enable_service():
+            async def sample_enable_service():
                 # Create a client
-                client = service_usage_v1.ServiceUsageClient()
+                client = service_usage_v1.ServiceUsageAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_usage_v1.EnableServiceRequest(
@@ -234,7 +234,7 @@ class ServiceUsageAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -277,7 +277,12 @@ class ServiceUsageAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -307,14 +312,13 @@ class ServiceUsageAsyncClient:
         ``FAILED_PRECONDITION`` status if the target service is not
         currently enabled.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
 
-            def sample_disable_service():
+            async def sample_disable_service():
                 # Create a client
-                client = service_usage_v1.ServiceUsageClient()
+                client = service_usage_v1.ServiceUsageAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_usage_v1.DisableServiceRequest(
@@ -325,7 +329,7 @@ class ServiceUsageAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -368,7 +372,12 @@ class ServiceUsageAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -392,21 +401,20 @@ class ServiceUsageAsyncClient:
         r"""Returns the service configuration and enabled state
         for a given service.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
 
-            def sample_get_service():
+            async def sample_get_service():
                 # Create a client
-                client = service_usage_v1.ServiceUsageClient()
+                client = service_usage_v1.ServiceUsageAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_usage_v1.GetServiceRequest(
                 )
 
                 # Make the request
-                response = client.get_service(request=request)
+                response = await client.get_service(request=request)
 
                 # Handle the response
                 print(response)
@@ -445,7 +453,12 @@ class ServiceUsageAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -473,14 +486,13 @@ class ServiceUsageAsyncClient:
         which provides higher throughput and richer filtering
         capability.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
 
-            def sample_list_services():
+            async def sample_list_services():
                 # Create a client
-                client = service_usage_v1.ServiceUsageClient()
+                client = service_usage_v1.ServiceUsageAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_usage_v1.ListServicesRequest(
@@ -490,7 +502,7 @@ class ServiceUsageAsyncClient:
                 page_result = client.list_services(request=request)
 
                 # Handle the response
-                for response in page_result:
+                async for response in page_result:
                     print(response)
 
         Args:
@@ -529,12 +541,20 @@ class ServiceUsageAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__aiter__` convenience method.
         response = pagers.ListServicesAsyncPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -553,14 +573,13 @@ class ServiceUsageAsyncClient:
         no state changes occur. To enable a single service, use the
         ``EnableService`` method instead.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
 
-            def sample_batch_enable_services():
+            async def sample_batch_enable_services():
                 # Create a client
-                client = service_usage_v1.ServiceUsageClient()
+                client = service_usage_v1.ServiceUsageAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_usage_v1.BatchEnableServicesRequest(
@@ -571,7 +590,7 @@ class ServiceUsageAsyncClient:
 
                 print("Waiting for operation to complete...")
 
-                response = operation.result()
+                response = await operation.result()
 
                 # Handle the response
                 print(response)
@@ -614,7 +633,12 @@ class ServiceUsageAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation_async.from_gapic(
@@ -638,21 +662,20 @@ class ServiceUsageAsyncClient:
         r"""Returns the service configurations and enabled states
         for a given list of services.
 
-
         .. code-block:: python
 
             from google.cloud import service_usage_v1
 
-            def sample_batch_get_services():
+            async def sample_batch_get_services():
                 # Create a client
-                client = service_usage_v1.ServiceUsageClient()
+                client = service_usage_v1.ServiceUsageAsyncClient()
 
                 # Initialize request argument(s)
                 request = service_usage_v1.BatchGetServicesRequest(
                 )
 
                 # Make the request
-                response = client.batch_get_services(request=request)
+                response = await client.batch_get_services(request=request)
 
                 # Handle the response
                 print(response)
@@ -689,7 +712,12 @@ class ServiceUsageAsyncClient:
         )
 
         # Send the request.
-        response = await rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = await rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
